# Ideal Engine


This is a project manager which I am building to handle my projects.   
I haven't really thought much about it, but here are my ideas:

- [x] Store files in text files   
- [ ] Add pickle support   
> so that people cannot read binary files, maybe encrypt it?

### TODO

1. Create WebView?   
2. Manage virtual environments?   
3. Pip manager?   
4. umm...idk actually lol.   

All I can say is, keep watching this space.
